==> nextcloud-18.0.4.tgz: nextcloud/apps/serverinfo/l10n/sk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "Load average" : "Priemerné zaťaženie",
    "Last minute" : "Posledná minúta",
    "Memory info not available" : "Informácie o pamäti nie sú dostupné",
    "Total" : "Celkovo",
    "Current usage" : "Aktuálne využitie",
    "Users" : "Používatelia",
    "Groups" : "Skupiny",
    "Links" : "Odkazy",
    "Mails" : "Maily",
    "Federated sent" : "Odoslané do Zduženého Cloudu",
    "Federated received" : "Prijaté zo Združeného Cloudu",
    "Talk conversations" : "Diskusné rozhovory",
    "24 hours" : "24 hodín",
    "1 hour" : "1 hodina",
    "5 mins" : "5 minút",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System" : "Operačný systém",
    "CPU" : "CPU",
    "Memory" : "Pamäť",
    "Server time" : "Čas servera",
    "Uptime" : "Doba behu",
    "Time Servers" : "Servery času",
    "Load" : "Záťaž",
    "Disk" : "Disk",
    "Mount" : "Prípojný bod",
    "Filesystem" : "Súborový systém",
    "Size" : "Veľkosť",
    "Available" : "Dostupné",
    "Used" : "Použité",
    "You will get a notification once one of your disks is nearly full." : "Ak je niektorý z vašich diskov skoro plný, dostanete varovanie.",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname" : "Názov servera",
    "DNS" : "DNS",
    "Gateway" : "Brána",
    "Status" : "Stav",
    "Speed" : "Rýchlosť",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktívni používatelia",
    "Total users:" : "Užívateľov celkom:",
    "Shares" : "Sprístupnené položky",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory Limit:" : "Obmedzenie pamäte:",
    "Max Execution Time:" : "Maximálny čas pre spustenie:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "Size:" : "Veľkosť:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
    "Did you know?" : "Vedeli ste?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Pridaním \"?format=json\" na koniec URL získate výsledok vo formáte JSON!",
    "Last 24 hours" : "Posledných 24 hodín",
    "Last 1 hour" : "Posledná 1 hodina",
    "Last 5 mins" : "Posledných 5 minút",
    "CPU load" : "Zaťaženie CPU",
    "Memory usage" : "Využitie pamäte",
    "Storage" : "Úložisko",
    "Users:" : "Používatelia:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Nainštalované aplikácie:",
    "Apps updates available:" : "Dostupné aktualizácie aplikácií:"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/serverinfo/l10n/sk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info o CPU nie je dostupné",
    "Load average" : "Priemerné zaťaženie",
    "Last minute" : "Posledná minúta",
    "Memory info not available" : "Informácie o pamäti nie sú dostupné",
    "Total" : "Celkovo",
    "Current usage" : "Aktuálne využitie",
    "Users" : "Používatelia",
    "Groups" : "Skupiny",
    "Links" : "Odkazy",
    "Mails" : "Maily",
    "Federated sent" : "Odoslané do Zduženého Cloudu",
    "Federated received" : "Prijaté zo Združeného Cloudu",
    "Talk conversations" : "Diskusné rozhovory",
    "24 hours" : "24 hodín",
    "1 hour" : "1 hodina",
    "5 mins" : "5 minút",
    "Copy" : "Kopírovať",
    "Copied!" : "Skopírované!",
    "Not supported!" : "Nepodporované!",
    "Press ⌘-C to copy." : "Pre kopírovanie, stlačte ⌘-C.",
    "Press Ctrl-C to copy." : "Pre kopírovanie, stlačte Ctrl-C.",
    "System" : "Systém",
    "Monitoring" : "Sledovanie",
    "Monitoring app with useful server information" : "Monitorovacia apka s užitočnými informáciami o serveri",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o serveri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
    "Operating System" : "Operačný systém",
    "CPU" : "CPU",
    "Memory" : "Pamäť",
    "Server time" : "Čas servera",
    "Uptime" : "Doba behu",
    "Time Servers" : "Servery času",
    "Load" : "Záťaž",
    "Disk" : "Disk",
    "Mount" : "Prípojný bod",
    "Filesystem" : "Súborový systém",
    "Size" : "Veľkosť",
    "Available" : "Dostupné",
    "Used" : "Použité",
    "You will get a notification once one of your disks is nearly full." : "Ak je niektorý z vašich diskov skoro plný, dostanete varovanie.",
    "Files:" : "Súbory:",
    "Storages:" : "Úložiská:",
    "Free Space:" : "Voľné miesto:",
    "Network" : "Sieť",
    "Hostname" : "Názov servera",
    "DNS" : "DNS",
    "Gateway" : "Brána",
    "Status" : "Stav",
    "Speed" : "Rýchlosť",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktívni používatelia",
    "Total users:" : "Užívateľov celkom:",
    "Shares" : "Sprístupnené položky",
    "PHP" : "PHP",
    "Version:" : "Verzia:",
    "Memory Limit:" : "Obmedzenie pamäte:",
    "Max Execution Time:" : "Maximálny čas pre spustenie:",
    "Upload max size:" : "Maximálna veľkosť pre nahratie:",
    "Database" : "Databáza",
    "Type:" : "Typ:",
    "Size:" : "Veľkosť:",
    "External monitoring tool" : "Externý sledovací nástroj",
    "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ak na koniec adresy URL pridáte „?format = json“, získate výsledok v JSON.",
    "Did you know?" : "Vedeli ste?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Pridaním \"?format=json\" na koniec URL získate výsledok vo formáte JSON!"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
